@@ -23,6 +23,14 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         self::$exampleDataLength = 10000;
     }
 
+    public function testBadHostname()
+    {
+        $this->setExpectedException('PHPUnit_Framework_Error_Notice');
+
+        $sftp = new Net_SFTP('bad host name');
+        $sftp->login('username', 'password');
+    }
+
     public function testConstructor()
     {
         $sftp = new Net_SFTP($this->getEnv('SSH_HOSTNAME'));
@@ -613,6 +621,12 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
             'Failed asserting that stat on a deleted directory returns false'
         );
 
+        $this->assertFalse(
+            $sftp->delete(self::$scratchDir),
+            'Failed asserting that non-existent directory could not ' .
+            'be deleted using recursive delete().'
+        );
+
         return $sftp;
     }
 
@@ -746,5 +760,22 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $list_cache_disabled = $sftp->rawlist('.', true);
 
         $this->assertEquals($list_cache_enabled, $list_cache_disabled, 'The files should be the same regardless of stat cache', 0.0, 10, true);
+
+        return $sftp;
+    }
+
+    /**
+     * @depends testRawlistDisabledStatCache
+     */
+    public function testChownChgrp($sftp)
+    {
+        $stat = $sftp->stat(self::$scratchDir);
+        $this->assertTrue($sftp->chown(self::$scratchDir, $stat['uid']));
+        $this->assertTrue($sftp->chgrp(self::$scratchDir, $stat['gid']));
+
+        $sftp->clearStatCache();
+        $stat2 = $sftp->stat(self::$scratchDir);
+        $this->assertSame($stat['uid'], $stat2['uid']);
+        $this->assertSame($stat['gid'], $stat2['gid']);
     }
 }
